<?php
namespace app\cms\event;

use app\common\controller\Addon;

class Seo extends Addon
{
    public function _initialize()
    {
        parent::_initialize();
    }
    
    public function index()
    {
        $items = [
            'rewrite_index' => [
                'type'        => 'text', 
                'value'       => config('cms.rewrite_index'),
                'tips'        => 'cms$',
            ],
            'rewrite_category' => [
                'type'        => 'text', 
                'value'       => config('cms.rewrite_category'),
                'tips'        => '[:id] [:slug] [:name] [:pageNumber]',
            ],
            'rewrite_tag' => [
                'type'        => 'text',
                'value'       => config('cms.rewrite_tag'),
                'tips'        => '[:id] [:slug] [:name] [:pageNumber]',
            ],
            'rewrite_search' => [
                'type'        => 'text',
                'value'       => config('cms.rewrite_search'),
                'tips'        => '[:searchText] [:pageNumber]',
            ],
            'rewrite_detail' => [
                'type'        => 'text',
                'value'       => config('cms.rewrite_detail'),
                'tips'        => '[:id] [:slug] [:name] [:termId] [:termSlug] [:termName]',
            ],
            'hr' => [
                'type'        => 'html',
                'value'       => '<hr>',
            ],
            'sitemap_limit' => [
                'type'        => 'number',
                'value'       => DcEmpty(config('cms.sitemap_limit'),10),
            ],
            'sitemap_max' => [
                'type'        => 'number',
                'value'       => intval(config('cms.sitemap_max')),
            ],
            'sitemap_start' => [
                'type'        => 'number',
                'value'       => intval(config('cms.sitemap_start')),
            ],
        ];
        
        foreach($items as $key=>$value){
            $items[$key]['title']  = lang('cms_'.$key);
        }
        
        $this->assign('items', DcFormItems($items));
        
        return $this->fetch('cms@seo/index');
    }
    
    public function update()
    {
        $post   = input('post.');
        $status = \daicuo\Op::write($post, 'cms', 'config', 'system', 0, 'yes');
		if( !$status ){
		    $this->error(lang('fail'));
        }
        //处理伪静态路由
        $this->rewriteRoute($post);
        //返回结果
        $this->success(lang('success'));
    }
    
    //配置伪静态
    private function rewriteRoute($post)
    {
        //批量删除路由伪静态
        \daicuo\Op::delete_all([
            'op_name'     => ['eq','site_route'],
            'op_module'   => ['eq','cms'],
            'op_action'   => ['eq','index'],
        ]);
        //批量添加路由伪静态
        $result = \daicuo\Route::save_all([
            [
                'rule'        => $post['rewrite_index'],
                'address'     => 'cms/index/index',
                'method'      => '*',
                'op_module'   => 'cms',
                'op_action'   => 'index',
                'op_order'    => -1,
            ],
            [
                'rule'        => $post['rewrite_detail'],
                'address'     => 'cms/detail/index',
                'pattern'     => json_encode(['id'=>'\d+','slug'=>'[0-9a-zA-Z]+','termId'=>'\d+','termSlug'=>'[0-9a-zA-Z]+']),
                'method'      => '*',
                'op_module'   => 'cms',
                'op_action'   => 'index',
                'op_order'    => -2,
            ],
            [
                'rule'        => $post['rewrite_category'],
                'address'     => 'cms/category/index',
                'pattern'     => json_encode(['id'=>'\d+','slug'=>'[0-9a-zA-Z]+']),
                'method'      => '*',
                'op_module'   => 'cms',
                'op_action'   => 'index',
                'op_order'    => -3,
            ],
            [
                'rule'        => $post['rewrite_tag'],
                'address'     => 'cms/tag/index',
                'pattern'     => json_encode(['id'=>'\d+','slug'=>'[0-9a-zA-Z]+']),
                'method'      => '*',
                'op_module'   => 'cms',
                'op_action'   => 'index',
                'op_order'    => -4,
            ],
            [
                'rule'        => $post['rewrite_search'],
                'address'     => 'cms/search/index',
                'method'      => '*',
                'op_module'   => 'cms',
                'op_action'   => 'index',
                'op_order'    => -5,
            ],
        ]);
        //清理全局缓存
        DcCache('route_all', null);
    }
}